@@ -1,5 +1,5 @@
 package Reply::Plugin::Prompt;
-$Reply::Plugin::Prompt::VERSION = '0.0.20.0';
+$Reply::Plugin::Prompt::VERSION = '0.0.21.0';
 use strict;
 use warnings;
 use Cwd qw(abs_path getcwd);
@@ -52,7 +52,9 @@ sub section_wakatime {
     my $cmd = $wakatime_cmd;
     if ( $cmd =~ /%s/ ) {
         my $null    = $^O eq 'MSWin32' ? 'nul' : '/dev/null';
+        my $old     = $?;
         my $project = `git rev-parse --show-toplevel 2> $null`;
+        $? = $old;
         chomp $project;
         $project = abs_path getcwd if $project eq '';
         $project = basename $project;
@@ -230,7 +232,7 @@ Reply::Plugin::Prompt - reply plugin for powerlevel10k style prompt
 
 =head1 VERSION
 
-version 0.0.20.0
+version 0.0.21.0
 
 =head1 DESCRIPTION
 
